@@ -53,6 +53,8 @@ class DefectDojoPlatform(VulnerabilityManagementGateway):
                 "CHECKOV": "Checkov Scan",
                 "PRISMA": "Twistlock Image Scan",
                 "XRAY": "JFrog Xray On Demand Binary Scan",
+                "TRUFFLEHOG": "Trufflehog Scan",
+                "TRIVY": "Trivy Scan",
             }
 
             if any(
@@ -60,7 +62,7 @@ class DefectDojoPlatform(VulnerabilityManagementGateway):
                 for branch in vulnerability_management.config_tool[
                     "VULNERABILITY_MANAGER"
                 ]["BRANCH_FILTER"].split(",")
-            ):
+            ) or (vulnerability_management.dict_args["tool"] == 'engine_secret'):
                 request: ImportScanRequest = Connect.cmdb(
                     cmdb_mapping={
                         "product_type_name": "nombreevc",
