@@ -4,14 +4,23 @@ from devsecops_engine_tools.engine_sast.engine_iac.src.infrastructure.entry_poin
 from devsecops_engine_tools.engine_sast.engine_iac.src.infrastructure.driven_adapters.checkov.checkov_tool import (
     CheckovTool
 )
+from devsecops_engine_tools.engine_sast.engine_iac.src.infrastructure.driven_adapters.kubescape.kubescape_tool import (
+    KubescapeTool
+)
 
 
 def runner_engine_iac(dict_args, tool, secret_tool, devops_platform_gateway, env):
     try:
         # Define driven adapters for gateways
         tool_gateway = None
-        if (tool == "CHECKOV"):
-            tool_gateway = CheckovTool()
+
+        tools = {
+            "CHECKOV": CheckovTool(),
+            "KUBESCAPE": KubescapeTool(),
+        }
+
+        if tool in tools:
+            tool_gateway = tools[tool]
 
         return init_engine_sast_rm(
             devops_platform_gateway=devops_platform_gateway,
